[PATCH] D76442: [mlir/quant] fix a small typo in the quant utility

Feng Liu via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Fri Mar 20 10:18:05 PDT 2020


This revision was automatically updated to reflect the committed changes.
Closed by commit rG942afe0cb2ac: [mlir/quant] fix a small typo in the quant utility (authored by liufengdb).

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D76442/new/

https://reviews.llvm.org/D76442

Files:
  mlir/lib/Dialect/Quant/Utils/UniformSupport.cpp


Index: mlir/lib/Dialect/Quant/Utils/UniformSupport.cpp
===================================================================
--- mlir/lib/Dialect/Quant/Utils/UniformSupport.cpp
+++ mlir/lib/Dialect/Quant/Utils/UniformSupport.cpp
@@ -46,8 +46,8 @@
 
   switch (inputType.getKind()) {
   default:
-    if (isQuantizablePrimitiveType(elementalType)) {
-      // For primitives, just use the new elemental type.
+    if (elementalType.getExpressedType() == expressedType) {
+      // If the expressed types match, just use the new elemental type.
       return elementalType;
     }
     // Unsupported.


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D76442.251690.patch
Type: text/x-patch
Size: 598 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20200320/1489e959/attachment.bin>


More information about the llvm-commits mailing list